SystemOrganization addCategory: #'PW-Request'!

!ALHtmlResource methodsFor: '*pw-request' stamp: 'chc 1/4/2016 10:39'!
renderOnStream: out locator: aLocator
	| context |
	context := ALRenderingContext resource: self locator: aLocator.
	^ component renderOn: (ALAppHtml5Canvas context: context stream: out)! !

!ALResponse class methodsFor: '*pw-request' stamp: 'chc 1/27/2015 15:08'!
unauthorized
	^ self status: 401 reason: 'Unauthorized' details: 'You have not logged in'! !

ALExampleApplication subclass: #PWExampleApplication
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Request'!

!PWExampleApplication methodsFor: 'as yet unclassified' stamp: 'chc 6/21/2016 08:06'!
initializeLocator
	| docroot |
	locator 
		at: ALPath root 
		put: ALExamplePage new asResource.
	locator 
		at: ALPath root / 'config'
		put: (PWBasicAuthResource component: (PWConfigPage new)).
	"locator at: (ALPath / 'jquery.form.js')
		put: (ALFileResource on: (FSLocator imageDirectory / 'jquery.form.js') resolve)."
	locator at: (ALPath / 'favicon.ico')
		put: (ALFileResource on: (FSLocator imageDirectory / 'oopluflavicon.ico') resolve).
	locator at: (ALPath / 'sunglasses.png')
		put: (ALFileResource on: (FSLocator imageDirectory / 'sunglasses.png') resolve).

	docroot := FSLocator imageDirectory.
	ALDirectoryScanner scan: docroot into: locator.
	"locator 
		at: ALPath root 
		put: (ALHtmlResource component: ALAmberIndexPage new)"! !

ALComponentResource subclass: #PWBasicAuthResource
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Request'!

!PWBasicAuthResource commentStamp: 'chc 3/22/2016 09:30' prior: 0!
Drops down browser window for username and password.!

!PWBasicAuthResource methodsFor: 'as yet unclassified' stamp: 'chc 6/23/2015 16:39'!
authorized: result locator: aLocator
	| root cookie url |
	root := component rematerialize.
	url := aLocator urlForResource: root asResource.
	cookie := ALCookie name: 'auth' value: result token.
	cookie path: '/'.
	^ (ALResponse seeOther: url)
			setCookie: cookie; 
			yourself! !

!PWBasicAuthResource methodsFor: 'as yet unclassified' stamp: 'chc 2/3/2015 16:08'!
denied
	^ ALResponse status: 401 reason: 'Authentication failed'! !

!PWBasicAuthResource methodsFor: 'as yet unclassified' stamp: 'chc 2/10/2015 15:46'!
handleGet: aRequest locator: aLocator
	| request result authstring |
	(aRequest authorization isNil)
		ifTrue: [^self respondWithChallenge]
		ifFalse: [
	authstring := (aRequest authorization copyAfter: Character space) base64Decoded.
	request := ALAuthenticationRequest withUsername:  (authstring copyUpTo: $:)   password: (authstring copyAfter: $:).
	result := request signal].
	^(result notNil and: [result isSuccess])
		ifTrue: [self authorized: result locator: aLocator]
		ifFalse: [ self denied ]
			! !

!PWBasicAuthResource methodsFor: 'as yet unclassified' stamp: 'chc 2/3/2015 16:15'!
respondWithChallenge
	^ALResponse unauthorized
		wwwAuthenticate: 'Basic Realm = "My Server"';
			yourself! !

Object subclass: #PWJsonToWikiStringRequest
	instanceVariableNames: 'wikiString'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-Request'!

!PWJsonToWikiStringRequest commentStamp: 'chc 6/28/2016 10:35' prior: 0!
This category is for resources, requests, application classes and HTTP related things. !

!PWJsonToWikiStringRequest class methodsFor: 'as yet unclassified' stamp: 'chc 8/18/2015 13:41'!
username: username password: password
	^ (self withUsername: username password: password) signal! !

!PWJsonToWikiStringRequest class methodsFor: 'as yet unclassified' stamp: 'chc 8/18/2015 13:41'!
withUsername: username password: password
	^ self basicNew
		initializeWithUsername: username password: password! !

!PWJsonToWikiStringRequest methodsFor: 'initialization' stamp: 'chc 8/18/2015 13:42'!
initializeWithUsername: aUsername password: aPassword
	self initialize.
	! !

!PWJsonToWikiStringRequest methodsFor: 'interpreting' stamp: 'chc 8/18/2015 13:53'!
name: aString value: anObject
	aString = 'wikiString' ifTrue: [wikiString := anObject].
	! !

!PWJsonToWikiStringRequest methodsFor: 'interpreting' stamp: 'chc 8/18/2015 13:41'!
object: aBlock
	aBlock value
	! !

!PWJsonToWikiStringRequest methodsFor: 'accessing' stamp: 'chc 8/18/2015 13:42'!
wikiString

	^ wikiString! !

!PWJsonToWikiStringRequest methodsFor: 'accessing' stamp: 'chc 8/18/2015 13:42'!
wikiString: anObject

	wikiString := anObject! !

!ALJsonResource methodsFor: '*pw-request' stamp: 'chc 11/30/2016 11:07'!
handlePost: aRequest locator: aLocator
	| request wikiString wikiGrammar parser html |
	request := PWJsonToWikiStringRequest new.
	aRequest readEntityWith: 
		[:in | ALJsonParser  parse: in for: request].
	"put new wiki string in the class var"
	wikiString := (request wikiString) withSqueakLineEndings.
	PWSeasidePrefsModel instance takeValue: wikiString forAttribute: (WAStringAttribute key: #currentString group: #wikidata).
	"make string to put in component"
	wikiGrammar := PEGParser grammarWiki.
	parser := PEGParser parserPEG parse: 'Grammar' stream: wikiGrammar actor: PEGParserParser new.
	html := parser parse: 'Page' stream: wikiString actor: PWWikiActor new.
	self component html: html.
	"return response"
	"do I need a redirect so that the GET is activated?"
 	^ ALResponse 
		type: ALContentType json 
		callback: [ :out | self renderOnStream: out locator: aLocator ]

! !

!ALJsonResource methodsFor: '*pw-request' stamp: 'chc 1/4/2016 10:41'!
renderOnStream: out locator: aLocator
	| context |
	context := ALRenderingContext resource: self locator: aLocator.
	^ self component renderOn: (ALJsonRenderer context: context stream: out)! !
